--- media_gallery/media_gallery.fields.inc
+++ media_gallery/media_gallery.fields.inc
@@ -248,8 +248,9 @@ function _media_gallery_get_format_value
  */
 function _media_gallery_get_lightbox_extras_values() {
   return array(
-    0 => t('Do not show title and description'),
-    1 => t('Show title and description'),
+    'nothing' => t('Do not show title and description'),
+    'title' => t('Show only title'),
+    'title_and_description' => t('Show title and description'),
   );
 }
 
--- media_gallery/media_gallery.install
+++ media_gallery/media_gallery.install
@@ -207,7 +207,7 @@ function _media_gallery_controlled_field
       'field_name' => 'media_gallery_lightbox_extras',
       'cardinality' => 1,
       'locked' => TRUE,
-      'type' => 'list_boolean',
+      'type' => 'list_text',
       'settings' => array(
         'allowed_values_function' => '_media_gallery_get_lightbox_extras_values',
       ),
@@ -431,10 +431,10 @@ function _media_gallery_controlled_insta
     'media_gallery_lightbox_extras' => array(
       'field_name' => 'media_gallery_lightbox_extras',
       'label' => 'Lightbox title and description',
-      'description' => $t('Show title and description'),
-      'default_value' => array(array('value' => 0)),
+      'description' => $t('Show/Hide title and/or description'),
+      'default_value' => array(array('value' => 'nothing')),
       'widget' => array(
-        'type' => 'options_onoff',
+        'type' => 'options_select',
       ),
       'display' => array(
         'default' => array(
@@ -1008,7 +1008,7 @@ function media_gallery_update_7000() {
     'field_name' => 'media_gallery_lightbox_extras',
     'cardinality' => 1,
     'locked' => TRUE,
-    'type' => 'list_boolean',
+    'type' => 'list_text',
     'settings' => array(
       'allowed_values_function' => '_media_gallery_get_lightbox_extras_values',
     ),
@@ -1018,12 +1018,12 @@ function media_gallery_update_7000() {
   $newInstance = array(
     'field_name' => 'media_gallery_lightbox_extras',
     'label' => 'Lightbox title and description',
-    'description' => $t('Show title and description'),
-    'default_value' => array(array('value' => 0)),
+    'description' => $t('Show/Hide title and/or description'),
+    'default_value' => array(array('value' => 'nothing')),
     'entity_type' => 'node',
     'bundle' => 'media_gallery',
     'widget' => array(
-      'type' => 'options_onoff',
+      'type' => 'options_select',
     ),
     'display' => array(
       'default' => array(
@@ -1056,7 +1056,7 @@ function media_gallery_update_7001() {
     $node = node_load($record->nid);
     if ($node->media_gallery_format[LANGUAGE_NONE][0]['value'] == 'lightbox_text') {
       $node->media_gallery_format[LANGUAGE_NONE][0]['value'] = 'lightbox';
-      $node->media_gallery_lightbox_extras[LANGUAGE_NONE][0]['value'] = 0;
+      $node->media_gallery_lightbox_extras[LANGUAGE_NONE][0]['value'] = 'nothing';
       node_save($node);
     }
   }
@@ -1164,10 +1164,10 @@ function media_gallery_update_7006() {
     $field = array(
       'field_name' => 'media_gallery_lightbox_extras',
       'label' => 'Lightbox title and description',
-      'description' => 'Show title and description',
-      'default_value' => array(array('value' => 0)),
+      'description' => 'Show/Hide title and/or description',
+      'default_value' => array(array('value' => 'nothing')),
       'widget' => array(
-        'type' => 'options_onoff',
+        'type' => 'options_select',
       ),
       'display' => array(
         'default' => array(
@@ -1192,12 +1192,12 @@ function media_gallery_update_7006() {
     $instance = array(
       'field_name' => 'media_gallery_lightbox_extras',
       'label' => 'Lightbox title and description',
-      'description' => 'Show title and description',
-      'default_value' => array(array('value' => 0)),
+      'description' => 'Show/Hide title and/or description',
+      'default_value' => array(array('value' => 'nothing')),
       'entity_type' => 'node',
       'bundle' => 'media_gallery',
       'widget' => array(
-        'type' => 'options_onoff',
+        'type' => 'options_select',
       ),
       'display' => array(
         'default' => array(

--- media_gallery/media_gallery.module
+++ media_gallery/media_gallery.module
@@ -970,6 +970,11 @@ function media_gallery_form_media_galler
   // @todo At some point, it would be nice to have a functional preview display
   //   of gallery nodes, but until happens, remove the Preview button.
   $form['actions']['preview']['#access'] = FALSE;
+
+  // unset None option from Lightbox title and description field.
+  if (isset($form['settings_wrapper']['presentation']['media_gallery_lightbox_extras'][LANGUAGE_NONE]['#options']['_none'])) {
+    unset($form['settings_wrapper']['presentation']['media_gallery_lightbox_extras'][LANGUAGE_NONE]['#options']['_none']);
+  }
 }
 
 /**

--- media_gallery/media_gallery.theme.inc
+++ media_gallery/media_gallery.theme.inc
@@ -231,16 +231,22 @@ function theme_media_gallery_media_item_
 
   $output = 'Error';
   // If the format is to have the description as well, we add it here
-  if (!empty($gallery_node->media_gallery_lightbox_extras[LANGUAGE_NONE][0]['value'])) {
-    $output =
-    '<div class="mg-lightbox-wrapper clearfix">' .
-      '<div class="lightbox-title">' . drupal_render($element['media_title']) . '</div>' .
-      '<div class="mg-lightbox-detail">' .
-      $media_gallery_detail .
-      '</div><div class="mg-lightbox-description">' .
-        drupal_render_children($element) .
-      '</div>' .
-    '</div>';
+  if (!empty($gallery_node->media_gallery_lightbox_extras[LANGUAGE_NONE][0]['value']) && $gallery_node->media_gallery_lightbox_extras[LANGUAGE_NONE][0]['value'] != 'nothing') {
+    $output = '<div class="mg-lightbox-wrapper clearfix">';
+    if ($gallery_node->media_gallery_lightbox_extras[LANGUAGE_NONE][0]['value'] == 'title_and_description') {
+      $output .= 
+        '<div class="lightbox-title">' . drupal_render($element['media_title']) . '</div>' .
+        '<div class="mg-lightbox-detail">' .
+          $media_gallery_detail .
+        '</div><div class="mg-lightbox-description">' .
+          drupal_render_children($element) .
+        '</div>';
+    } else {
+      $output .= 
+        '<div class="lightbox-title">' . drupal_render($element['media_title']) . '</div>' .
+          $media_gallery_detail;
+    }
+    $output .= '</div>';
   } else {
     $output = $media_gallery_detail;
   }

--- media_gallery/media_gallery.form.js
+++ media_gallery/media_gallery.form.js
@@ -26,20 +26,20 @@ Drupal.behaviors.media_gallery_form.atta
 Drupal.behaviors.media_gallery_form.format_select = function (event) {
   var radioValue = $('.presentation-settings input:radio:checked').val();
   var icon = $('.presentation-settings .setting-icon');
-  var checkbox = $('.presentation-settings .field-name-media-gallery-lightbox-extras input');
+  var selectbox = $('.presentation-settings .field-name-media-gallery-lightbox-extras select');
 
   // Depending on the radio button chosen add a class
   if (radioValue == 'node') {
     icon.attr('class', 'setting-icon display-page');
-    // Disable the checkbox
-    checkbox.attr('disabled', true);
+    // Disable the selectbox
+    selectbox.attr('disabled', true);
   } else {
     icon.attr('class', 'setting-icon display-lightbox');
-    // Turn on the checkbox
-    checkbox.attr('disabled', false);
-    // Add a class if the checkbox is checked
-    if (checkbox.is(':checked')) {
-      icon.attr('class', 'setting-icon display-extras');
+    // Turn on the selectbox
+    selectbox.attr('disabled', false);
+    // Add a class if the selectbox option is selected
+    if (selectbox.find(":selected").text()) {
+	icon.attr('class', 'setting-icon display-extras');
     }
   }
 };
